@@ -9,9 +9,9 @@
 #include <CoreGraphics/CGDirectDisplay.h>
 #include <CoreVideo/CVDisplayLink.h>
 
+#ifdef MAC_OS_X_VERSION_10_15
 extern Boolean CoreDisplay_Display_SupportsHDRMode(CGDirectDisplayID display) __attribute__((weak_import));
 extern Boolean CoreDisplay_Display_IsHDRModeEnabled(CGDirectDisplayID display) __attribute__((weak_import));
-#ifdef MAC_OS_X_VERSION_10_15
 extern CFDictionaryRef CoreDisplay_DisplayCreateInfoDictionary(CGDirectDisplayID display) __attribute__((weak_import));
 #else
 #include <IOKit/graphics/IOGraphicsLib.h>
@@ -21,7 +21,7 @@ static void detectDisplays(FFDisplayServerResult* ds)
 {
     CGDirectDisplayID screens[128];
     uint32_t screenCount;
-    if(CGGetOnlineDisplayList(sizeof(screens) / sizeof(screens[0]), screens, &screenCount) != kCGErrorSuccess)
+    if(CGGetOnlineDisplayList(ARRAY_SIZE(screens), screens, &screenCount) != kCGErrorSuccess)
         return;
 
     FF_STRBUF_AUTO_DESTROY buffer = ffStrbufCreate();
@@ -36,6 +36,8 @@ static void detectDisplays(FFDisplayServerResult* ds)
 
             if (refreshRate == 0)
             {
+                #pragma clang diagnostic push
+                #pragma clang diagnostic ignored "-Wdeprecated-declarations"
                 CVDisplayLinkRef link;
                 if(CVDisplayLinkCreateWithCGDisplay(screen, &link) == kCVReturnSuccess)
                 {
@@ -44,6 +46,7 @@ static void detectDisplays(FFDisplayServerResult* ds)
                         refreshRate = time.timeScale / (double) time.timeValue; //59.97...
                     CVDisplayLinkRelease(link);
                 }
+                #pragma clang diagnostic pop
             }
 
             ffStrbufClear(&buffer);
@@ -94,10 +97,15 @@ static void detectDisplays(FFDisplayServerResult* ds)
                 CGDisplayIsMain(screen),
                 (uint64_t)screen,
                 physicalWidth,
-                physicalHeight
+                physicalHeight,
+                "CoreGraphics"
             );
             if (display)
             {
+                #ifndef MAC_OS_X_VERSION_10_11
+                FF_CFTYPE_AUTO_RELEASE CFStringRef pe = CGDisplayModeCopyPixelEncoding(mode);
+                if (pe) display->bitDepth = (uint8_t) (CFStringGetLength(pe) - CFStringFind(pe, CFSTR("B"), 0).location);
+                #else
                 // https://stackoverflow.com/a/33519316/9976392
                 // Also shitty, but better than parsing `CFCopyDescription(mode)`
                 CFDictionaryRef dict = (CFDictionaryRef) *((int64_t *)mode + 2);
@@ -107,10 +115,12 @@ static void detectDisplays(FFDisplayServerResult* ds)
                     ffCfDictGetInt(dict, kCGDisplayBitsPerSample, &bitDepth);
                     display->bitDepth = (uint8_t) bitDepth;
                 }
+                #endif
 
                 if (display->type == FF_DISPLAY_TYPE_BUILTIN)
                     display->hdrStatus = CFDictionaryContainsKey(displayInfo, CFSTR("ReferencePeakHDRLuminance"))
                         ? FF_DISPLAY_HDR_STATUS_SUPPORTED : FF_DISPLAY_HDR_STATUS_UNSUPPORTED;
+                #ifdef MAC_OS_X_VERSION_10_15
                 else if (CoreDisplay_Display_SupportsHDRMode)
                 {
                     if (CoreDisplay_Display_SupportsHDRMode(screen))
@@ -122,6 +132,7 @@ static void detectDisplays(FFDisplayServerResult* ds)
                     else
                         display->hdrStatus = FF_DISPLAY_HDR_STATUS_UNSUPPORTED;
                 }
+                #endif
 
                 display->serial = CGDisplaySerialNumber(screen);
                 int value;
