@@ -6,7 +6,7 @@
 
 #include <math.h>
 
-#define FF_DISPLAY_NUM_FORMAT_ARGS 18
+#define FF_DISPLAY_NUM_FORMAT_ARGS 20
 
 static int sortByNameAsc(FFDisplayResult* a, FFDisplayResult* b)
 {
@@ -75,7 +75,7 @@ void ffPrintDisplay(FFDisplayOptions* options)
 
     for(uint32_t i = 0; i < dsResult->displays.length; i++)
     {
-        FFDisplayResult* result = ffListGet(&dsResult->displays, i);
+        FFDisplayResult* result = FF_LIST_GET(FFDisplayResult, dsResult->displays, i);
         uint32_t moduleIndex = dsResult->displays.length == 1 ? 0 : i + 1;
         const char* displayType = result->type == FF_DISPLAY_TYPE_UNKNOWN ? NULL : result->type == FF_DISPLAY_TYPE_BUILTIN ? "built-in" : "external";
 
@@ -124,11 +124,21 @@ void ffPrintDisplay(FFDisplayOptions* options)
             if (inch > 1)
                 ffStrbufAppendF(&buffer, " in %i\"", (uint32_t) (inch + 0.5));
 
-            if(result->type != FF_DISPLAY_TYPE_UNKNOWN)
-                ffStrbufAppendS(&buffer, result->type == FF_DISPLAY_TYPE_BUILTIN ? " [Built-in]" : " [External]");
+            bool flag = false;
+            if (result->type != FF_DISPLAY_TYPE_UNKNOWN)
+            {
+                ffStrbufAppendS(&buffer, result->type == FF_DISPLAY_TYPE_BUILTIN ? " [Built-in" : " [External");
+                flag = true;
+            }
 
             if (result->hdrStatus == FF_DISPLAY_HDR_STATUS_ENABLED)
-                ffStrbufAppendS(&buffer, " [HDR]");
+            {
+                ffStrbufAppendS(&buffer, flag ? ", HDR" : " [HDR");
+                flag = true;
+            }
+
+            if (flag)
+                ffStrbufAppendS(&buffer, "]");
 
             if(moduleIndex > 0 && result->primary)
                 ffStrbufAppendS(&buffer, " *");
@@ -140,15 +150,16 @@ void ffPrintDisplay(FFDisplayOptions* options)
         {
             double ppi = sqrt(result->width * result->width + result->height * result->height) / inch;
             bool hdrEnabled = result->hdrStatus == FF_DISPLAY_HDR_STATUS_ENABLED;
+            bool hdrCompatible = result->hdrStatus == FF_DISPLAY_HDR_STATUS_SUPPORTED || result->hdrStatus == FF_DISPLAY_HDR_STATUS_ENABLED;
             uint32_t iInch = (uint32_t) (inch + 0.5), iPpi = (uint32_t) (ppi + 0.5);
 
             char refreshRate[16];
             if(result->refreshRate > 0)
             {
                 if(options->preciseRefreshRate)
-                    snprintf(refreshRate, sizeof(refreshRate), "%g", ((int) (result->refreshRate * 1000 + 0.5)) / 1000.0);
+                    snprintf(refreshRate, ARRAY_SIZE(refreshRate), "%g", ((int) (result->refreshRate * 1000 + 0.5)) / 1000.0);
                 else
-                    snprintf(refreshRate, sizeof(refreshRate), "%i", (uint32_t) (result->refreshRate + 0.5));
+                    snprintf(refreshRate, ARRAY_SIZE(refreshRate), "%i", (uint32_t) (result->refreshRate + 0.5));
             }
             else
                 refreshRate[0] = 0;
@@ -157,7 +168,7 @@ void ffPrintDisplay(FFDisplayOptions* options)
             if (result->serial)
             {
                 const uint8_t* nums = (uint8_t*) &result->serial;
-                snprintf(buf, sizeof(buf), "%2X-%2X-%2X-%2X", nums[0], nums[1], nums[2], nums[3]);
+                snprintf(buf, ARRAY_SIZE(buf), "%2X-%2X-%2X-%2X", nums[0], nums[1], nums[2], nums[3]);
             }
             else
                 buf[0] = '\0';
@@ -181,6 +192,8 @@ void ffPrintDisplay(FFDisplayOptions* options)
                 FF_FORMAT_ARG(result->manufactureYear, "manufacture-year"),
                 FF_FORMAT_ARG(result->manufactureWeek, "manufacture-week"),
                 FF_FORMAT_ARG(buf, "serial"),
+                FF_FORMAT_ARG(result->platformApi, "platform-api"),
+                FF_FORMAT_ARG(hdrCompatible, "hdr-compatible"),
             }));
         }
     }
@@ -395,6 +408,8 @@ void ffGenerateDisplayJsonResult(FF_MAYBE_UNUSED FFDisplayOptions* options, yyjs
             yyjson_mut_obj_add_uint(doc, obj, "serial", item->serial);
         else
             yyjson_mut_obj_add_null(doc, obj, "serial");
+
+        yyjson_mut_obj_add_str(doc, obj, "platformApi", item->platformApi);
     }
 }
 
@@ -419,6 +434,8 @@ void ffPrintDisplayHelpFormat(void)
         "Year of manufacturing - manufacture-year",
         "Nth week of manufacturing in the year - manufacture-week",
         "Serial number - serial",
+        "The platform API used when detecting the display - platform-api",
+        "True if the display is HDR compatible - hdr-compatible",
     }));
 }
 
