@@ -49,7 +49,7 @@ void ffPrintDNS(FFDNSOptions* options)
     else
     {
         FF_PRINT_FORMAT_CHECKED(FF_DNS_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, FF_DNS_NUM_FORMAT_ARGS, ((FFformatarg[]) {
-            {FF_FORMAT_ARG_TYPE_STRBUF, &buf, "result"},
+            FF_FORMAT_ARG(buf, "result"),
         }));
     }
 
@@ -122,6 +122,8 @@ void ffGenerateDNSJsonConfig(FFDNSOptions* options, yyjson_mut_doc* doc, yyjson_
 
     if (defaultOptions.showType != options->showType)
     {
+        #pragma GCC diagnostic push
+        #pragma GCC diagnostic ignored "-Wswitch" // FF_DNS_TYPE_FORCE_UNSIGNED
         switch (options->showType)
         {
             case FF_DNS_TYPE_IPV4_BIT:
@@ -134,6 +136,7 @@ void ffGenerateDNSJsonConfig(FFDNSOptions* options, yyjson_mut_doc* doc, yyjson_
                 yyjson_mut_obj_add_str(doc, module, "showType", "both");
                 break;
         }
+        #pragma GCC diagnostic pop
     }
 }
 
